@@ -2,6 +2,9 @@ class BasicResponse:
     msg: str
     res: int
 
+    def __repr__(self):
+        return str(self.__dict__)
+
 
 class CompleteBasicaResponse(BasicResponse):
 
