@@ -1,5 +1,3 @@
-
-
 from seti_python.class_tools import BasicResponse
 
 
@@ -9,8 +7,8 @@ class ResponseCreatePaymentData:
 
     def __init__(self, data: dict):
         try:
-            self.id = data['id']
-            self.url = data['url']
+            self.id = data["id"]
+            self.url = data["url"]
         except Exception:
             return
 
@@ -19,9 +17,11 @@ class ResponseCreatePayment(BasicResponse):
     data: ResponseCreatePaymentData
 
     def __init__(self, data: dict):
-        self.msg = data['msg']
-        self.res = data['res']
-        if data['res'] == 200:
-            self.data = ResponseCreatePaymentData(data['data'])
+        print("----------------------------------")
+        print(data)
+        self.msg = data["msg"]
+        self.res = data["res"]
+        if data["res"] == 200:
+            self.data = ResponseCreatePaymentData(data["data"])
         else:
             self.data = ResponseCreatePaymentData({})
